@@ -2,7 +2,7 @@
 # Package: High-dimensional Undirected Graph Estimation (HUGE)          #
 # huge.generator(): Data generator                                      #
 # Authors: Tuo Zhao and Han Liu                                         #
-# Emails: <tourzhao@andrew.cmu.edu>; <hanliu@cs.jhu.edu>                #
+# Emails: <tourzhao@gmail.com>; <hanliu@cs.jhu.edu>                     #
 # Date: Feb 27the 2011                                                  #
 # Version: 1.0								                            #
 #-----------------------------------------------------------------------#
@@ -132,14 +132,6 @@ print.sim = function(x, ...){
     cat("Sparsity level:", sum(x$theta)/ncol(x$data)/(ncol(x$data)-1),"\n")
 }
 
-summary.sim = function(object, ...){
-	cat("Simulated data generated by huge.generator()\n")
-	cat("Sample size: n =", nrow(object$data), "\n")
-	cat("Dimension: d =", ncol(object$data), "\n")
-	cat("Graph type = ", object$graph.type, "\n")
-	cat("Sparsity level:", sum(object$theta)/ncol(object$data)/(ncol(object$data)-1),"\n")
-}
-
 plot.sim = function(x, ...){
 	gcinfo(FALSE)	
    	par = par(mfrow = c(2, 2), pty = "s", omi=c(0.3,0.3,0.3,0.3), mai = c(0.3,0.3,0.3,0.3))
